@@ -1,4 +1,4 @@
-// Copyright 2018-2020 Cargill Incorporated
+// Copyright 2018-2021 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -21,6 +21,15 @@ extern crate log;
 #[macro_use]
 extern crate serde_derive;
 
+#[cfg(feature = "metrics")]
+#[macro_use]
+extern crate metrics;
+
+// pull in `no-op` metric macros if `metrics` is not enabled
+#[cfg(not(feature = "metrics"))]
+#[macro_use]
+extern crate splinter;
+
 #[cfg(feature = "client")]
 pub mod client;
 mod hex;
